This crate implements a Forth language interpreter in Rust that can be embedded in Rust applications as a scripting language.

Also provided is a Forth executable rtf as an example application using this library.

Re-exports

pub extern crate hibitset;

Modules

rtForth core words

Environemnt word set

Exception constants

Facility word set

File access word set

Floating-point word set

Source input

Memory access

Words output to console

Tools to inspect the rtforth system

Units

Constants

Type Definitions